==> pollen-ui-struts2-1.5-sources.jar: org/chorem/pollen/ui/actions/user/EditFavoriteList.java <==
package org.chorem.pollen.ui.actions.user;
/*
 * #%L
 * Pollen :: UI (struts2)
 * $Id: EditFavoriteList.java 3595 2012-08-12 11:45:39Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.5/pollen-ui-struts2/src/main/java/org/chorem/pollen/ui/actions/user/EditFavoriteList.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

import org.chorem.pollen.business.persistence.PersonList;
import org.chorem.pollen.services.exceptions.FavoriteListNotFoundException;
import org.chorem.pollen.services.exceptions.FavoriteListNotOwnedByUserException;
import org.chorem.pollen.ui.actions.PollenActionSupportForEdition;

/**
 * Edit a given {@link PersonList}.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.4.5
 */
public class EditFavoriteList extends PollenActionSupportForEdition {

    private static final long serialVersionUID = 1L;

    protected String favoriteListId;

    protected PersonList favoriteList;

    public void setFavoriteListId(String favoriteListId) {
        this.favoriteListId = favoriteListId;
    }

    public PersonList getFavoriteList() {
        return favoriteList;
    }

    public String getFavoriteListId() {
        return favoriteList.getTopiaId();
    }

    @Override
    public String execute() throws Exception {

        try {
            favoriteList = getFavoriteService().getFavoriteList(
                    getPollenUserAccount(), favoriteListId);
        } catch (FavoriteListNotFoundException e) {
            addFlashError(_("pollen.error.favoriteList.not.found"));
        } catch (FavoriteListNotOwnedByUserException e) {
            addFlashError(_("pollen.error.favoriteList.not.owned.by.user"));
        }
        return SUCCESS;
    }

}

==> pollen-ui-struts2-1.5.1-sources.jar: org/chorem/pollen/ui/actions/user/EditFavoriteList.java <==
package org.chorem.pollen.ui.actions.user;
/*
 * #%L
 * Pollen :: UI (struts2)
 * $Id: EditFavoriteList.java 3595 2012-08-12 11:45:39Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.5.1/pollen-ui-struts2/src/main/java/org/chorem/pollen/ui/actions/user/EditFavoriteList.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

import org.chorem.pollen.business.persistence.PersonList;
import org.chorem.pollen.services.exceptions.FavoriteListNotFoundException;
import org.chorem.pollen.services.exceptions.FavoriteListNotOwnedByUserException;
import org.chorem.pollen.ui.actions.PollenActionSupportForEdition;

/**
 * Edit a given {@link PersonList}.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.4.5
 */
public class EditFavoriteList extends PollenActionSupportForEdition {

    private static final long serialVersionUID = 1L;

    protected String favoriteListId;

    protected PersonList favoriteList;

    public void setFavoriteListId(String favoriteListId) {
        this.favoriteListId = favoriteListId;
    }

    public PersonList getFavoriteList() {
        return favoriteList;
    }

    public String getFavoriteListId() {
        return favoriteList.getTopiaId();
    }

    @Override
    public String execute() throws Exception {

        try {
            favoriteList = getFavoriteService().getFavoriteList(
                    getPollenUserAccount(), favoriteListId);
        } catch (FavoriteListNotFoundException e) {
            addFlashError(_("pollen.error.favoriteList.not.found"));
        } catch (FavoriteListNotOwnedByUserException e) {
            addFlashError(_("pollen.error.favoriteList.not.owned.by.user"));
        }
        return SUCCESS;
    }

}
